from yeying.api.common import message_pb2 as _message_pb2
from yeying.api.common import code_pb2 as _code_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class BulletinCodeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    BULLETIN_CODE_SOLUTION: _ClassVar[BulletinCodeEnum]

BULLETIN_CODE_SOLUTION: BulletinCodeEnum

class BulletinListRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: BulletinListRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[BulletinListRequestBody, _Mapping]] = ...,
    ) -> None: ...

class BulletinListRequestBody(_message.Message):
    __slots__ = ("code", "language", "page")
    CODE_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    code: BulletinCodeEnum
    language: _code_pb2.LanguageCodeEnum
    page: _message_pb2.RequestPage
    def __init__(
        self,
        code: _Optional[_Union[BulletinCodeEnum, str]] = ...,
        language: _Optional[_Union[_code_pb2.LanguageCodeEnum, str]] = ...,
        page: _Optional[_Union[_message_pb2.RequestPage, _Mapping]] = ...,
    ) -> None: ...

class BulletinListResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: BulletinListResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[BulletinListResponseBody, _Mapping]] = ...,
    ) -> None: ...

class BulletinListResponseBody(_message.Message):
    __slots__ = ("status", "solutions", "page")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    SOLUTIONS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    solutions: _containers.RepeatedCompositeFieldContainer[SolutionMetadata]
    page: _message_pb2.ResponsePage
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        solutions: _Optional[_Iterable[_Union[SolutionMetadata, _Mapping]]] = ...,
        page: _Optional[_Union[_message_pb2.ResponsePage, _Mapping]] = ...,
    ) -> None: ...

class SolutionMetadata(_message.Message):
    __slots__ = ("publisher", "language", "uid", "name", "description", "createdAt", "cards", "signature")
    PUBLISHER_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    UID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    CARDS_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    publisher: str
    language: _code_pb2.LanguageCodeEnum
    uid: str
    name: str
    description: str
    createdAt: str
    cards: _containers.RepeatedCompositeFieldContainer[SolutionCard]
    signature: str
    def __init__(
        self,
        publisher: _Optional[str] = ...,
        language: _Optional[_Union[_code_pb2.LanguageCodeEnum, str]] = ...,
        uid: _Optional[str] = ...,
        name: _Optional[str] = ...,
        description: _Optional[str] = ...,
        createdAt: _Optional[str] = ...,
        cards: _Optional[_Iterable[_Union[SolutionCard, _Mapping]]] = ...,
        signature: _Optional[str] = ...,
    ) -> None: ...

class SolutionCard(_message.Message):
    __slots__ = ("name", "price", "variables")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PRICE_FIELD_NUMBER: _ClassVar[int]
    VARIABLES_FIELD_NUMBER: _ClassVar[int]
    name: str
    price: str
    variables: str
    def __init__(
        self, name: _Optional[str] = ..., price: _Optional[str] = ..., variables: _Optional[str] = ...
    ) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/invitation/invitation.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/invitation/invitation.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n&yeying/api/invitation/invitation.proto\x12\x15yeying.api.invitation\x1a\x1fyeying/api/common/message.proto"\xb8\x01\n\x12InvitationMetadata\x12\x39\n\x05scene\x18\x01 \x01(\x0e\x32*.yeying.api.invitation.InvitationSceneEnum\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x11\n\tcreatedAt\x18\x03 \x01(\t\x12\x11\n\texpiredAt\x18\x04 \x01(\t\x12\x0f\n\x07inviter\x18\x05 \x01(\t\x12\x0f\n\x07invitee\x18\x06 \x01(\t\x12\x11\n\tsignature\x18\x07 \x01(\t"S\n\x12InvitationUseState\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0e\n\x06usedAt\x18\x02 \x01(\t\x12\x0c\n\x04user\x18\x03 \x01(\t\x12\x11\n\tsignature\x18\x04 \x01(\t"\x8d\x01\n\x17\x43reateInvitationRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.invitation.CreateInvitationRequestBody"\\\n\x1b\x43reateInvitationRequestBody\x12=\n\ninvitation\x18\x02 \x01(\x0b\x32).yeying.api.invitation.InvitationMetadata"\x8f\x01\n\x18\x43reateInvitationResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.invitation.CreateInvitationResponseBody"\x90\x01\n\x1c\x43reateInvitationResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12=\n\ninvitation\x18\x02 \x01(\x0b\x32).yeying.api.invitation.InvitationMetadata"\x8d\x01\n\x17SearchInvitationRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.invitation.SearchInvitationRequestBody"K\n\x1bSearchInvitationRequestBody\x12,\n\x04page\x18\x01 \x01(\x0b\x32\x1e.yeying.api.common.RequestPage"\x8f\x01\n\x18SearchInvitationResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.invitation.SearchInvitationResponseBody"\xc0\x01\n\x1cSearchInvitationResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12>\n\x0binvitations\x18\x02 \x03(\x0b\x32).yeying.api.invitation.InvitationMetadata\x12-\n\x04page\x18\x03 \x01(\x0b\x32\x1f.yeying.api.common.ResponsePage"\x8d\x01\n\x17InvitationDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12@\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x32.yeying.api.invitation.InvitationDetailRequestBody"+\n\x1bInvitationDetailRequestBody\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"\x8f\x01\n\x18InvitationDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.invitation.InvitationDetailResponseBody"\xca\x01\n\x1cInvitationDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12=\n\ninvitation\x18\x02 \x01(\x0b\x32).yeying.api.invitation.InvitationMetadata\x12\x38\n\x05state\x18\x03 \x01(\x0b\x32).yeying.api.invitation.InvitationUseState*N\n\x13InvitationSceneEnum\x12\x1c\n\x18INVITATION_SCENE_UNKNOWN\x10\x00\x12\x19\n\x15INVITATION_SCENE_USER\x10\x01\x32\xd3\x02\n\nInvitation\x12k\n\x06\x43reate\x12..yeying.api.invitation.CreateInvitationRequest\x1a/.yeying.api.invitation.CreateInvitationResponse"\x00\x12k\n\x06Search\x12..yeying.api.invitation.SearchInvitationRequest\x1a/.yeying.api.invitation.SearchInvitationResponse"\x00\x12k\n\x06\x44\x65tail\x12..yeying.api.invitation.InvitationDetailRequest\x1a/.yeying.api.invitation.InvitationDetailResponse"\x00\x42\x17Z\x15yeying/api/invitationb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.invitation.invitation_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\025yeying/api/invitation"
    _globals["_INVITATIONSCENEENUM"]._serialized_start = 2003
    _globals["_INVITATIONSCENEENUM"]._serialized_end = 2081
    _globals["_INVITATIONMETADATA"]._serialized_start = 99
    _globals["_INVITATIONMETADATA"]._serialized_end = 283
    _globals["_INVITATIONUSESTATE"]._serialized_start = 285
    _globals["_INVITATIONUSESTATE"]._serialized_end = 368
    _globals["_CREATEINVITATIONREQUEST"]._serialized_start = 371
    _globals["_CREATEINVITATIONREQUEST"]._serialized_end = 512
    _globals["_CREATEINVITATIONREQUESTBODY"]._serialized_start = 514
    _globals["_CREATEINVITATIONREQUESTBODY"]._serialized_end = 606
    _globals["_CREATEINVITATIONRESPONSE"]._serialized_start = 609
    _globals["_CREATEINVITATIONRESPONSE"]._serialized_end = 752
    _globals["_CREATEINVITATIONRESPONSEBODY"]._serialized_start = 755
    _globals["_CREATEINVITATIONRESPONSEBODY"]._serialized_end = 899
    _globals["_SEARCHINVITATIONREQUEST"]._serialized_start = 902
    _globals["_SEARCHINVITATIONREQUEST"]._serialized_end = 1043
    _globals["_SEARCHINVITATIONREQUESTBODY"]._serialized_start = 1045
    _globals["_SEARCHINVITATIONREQUESTBODY"]._serialized_end = 1120
    _globals["_SEARCHINVITATIONRESPONSE"]._serialized_start = 1123
    _globals["_SEARCHINVITATIONRESPONSE"]._serialized_end = 1266
    _globals["_SEARCHINVITATIONRESPONSEBODY"]._serialized_start = 1269
    _globals["_SEARCHINVITATIONRESPONSEBODY"]._serialized_end = 1461
    _globals["_INVITATIONDETAILREQUEST"]._serialized_start = 1464
    _globals["_INVITATIONDETAILREQUEST"]._serialized_end = 1605
    _globals["_INVITATIONDETAILREQUESTBODY"]._serialized_start = 1607
    _globals["_INVITATIONDETAILREQUESTBODY"]._serialized_end = 1650
    _globals["_INVITATIONDETAILRESPONSE"]._serialized_start = 1653
    _globals["_INVITATIONDETAILRESPONSE"]._serialized_end = 1796
    _globals["_INVITATIONDETAILRESPONSEBODY"]._serialized_start = 1799
    _globals["_INVITATIONDETAILRESPONSEBODY"]._serialized_end = 2001
    _globals["_INVITATION"]._serialized_start = 2084
    _globals["_INVITATION"]._serialized_end = 2423
# @@protoc_insertion_point(module_scope)



# Generated by protobuf_init. Do not edit manually.
from .identity_pb2 import DepositRequest
from .identity_pb2 import DepositRequestBody
from .identity_pb2 import DepositResponse
from .identity_pb2 import DepositResponseBody
from .identity_pb2 import RetrieveRequest
from .identity_pb2 import RetrieveResponse
from .identity_pb2 import ShareRequest
from .identity_pb2 import ShareResponse
from .identity_pb2 import QueryRequest
from .identity_pb2 import QueryRequestBody
from .identity_pb2 import QueryResponse
from .identity_pb2 import QueryResponseBody
from .identity_pb2 import CancelRequest
from .identity_pb2 import CancelRequestBody
from .identity_pb2 import CancelResponse
from .identity_pb2 import CancelResponseBody
from .identity_pb2_grpc import IdentityServicer
from .identity_pb2_grpc import IdentityStub
from .identity_pb2_grpc import add_IdentityServicer_to_server
from .identity_pb2_grpc import Identity



from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SupportCodeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SUPPORT_CODE_FAQ: _ClassVar[SupportCodeEnum]
    SUPPORT_CODE_CSR: _ClassVar[SupportCodeEnum]
    SUPPORT_CODE_IVR: _ClassVar[SupportCodeEnum]

SUPPORT_CODE_FAQ: SupportCodeEnum
SUPPORT_CODE_CSR: SupportCodeEnum
SUPPORT_CODE_IVR: SupportCodeEnum

class CollectSupportRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CollectSupportRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CollectSupportRequestBody, _Mapping]] = ...,
    ) -> None: ...

class CollectSupportRequestBody(_message.Message):
    __slots__ = ("code", "faq")
    CODE_FIELD_NUMBER: _ClassVar[int]
    FAQ_FIELD_NUMBER: _ClassVar[int]
    code: SupportCodeEnum
    faq: FaqMetadata
    def __init__(
        self, code: _Optional[_Union[SupportCodeEnum, str]] = ..., faq: _Optional[_Union[FaqMetadata, _Mapping]] = ...
    ) -> None: ...

class FaqMetadata(_message.Message):
    __slots__ = ("did", "email", "type", "description", "createdAt", "signature")
    DID_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    did: str
    email: str
    type: str
    description: str
    createdAt: str
    signature: str
    def __init__(
        self,
        did: _Optional[str] = ...,
        email: _Optional[str] = ...,
        type: _Optional[str] = ...,
        description: _Optional[str] = ...,
        createdAt: _Optional[str] = ...,
        signature: _Optional[str] = ...,
    ) -> None: ...

class CollectSupportResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CollectSupportResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CollectSupportResponseBody, _Mapping]] = ...,
    ) -> None: ...

class CollectSupportResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...



import uuid
import base64


def unicode_encode(name):
    return name.encode("unicode-escape").decode("utf-8")


def unicode_decode(name):
    return name.encode("utf-8").decode("unicode-escape")


def generate_uuid():
    return str(uuid.uuid4())


def is_empty(s):
    return False if s and not s.isspace() else True


def decode_base64(data: str) -> bytes:
    """
    解码 Base64 字符串为字节数组

    参数:
        data: Base64 编码的字符串

    返回:
        bytes: 解码后的字节数组
    """
    # 处理可能的填充问题（Python 的 base64 模块会自动处理）
    # 添加必要的 '=' 填充字符以确保字符串长度是4的倍数
    missing_padding = len(data) % 4
    if missing_padding:
        data += '=' * (4 - missing_padding)

    return base64.b64decode(data)


# -*- coding:utf-8 -*-
from yeying.api.web3 import SecurityAlgorithm
from yeying.client.model.option import ProviderOption
from yeying.client.provider.asset_provider import AssetProvider
from yeying.client.provider.block_provider import BlockProvider
from yeying.client.provider.config_provider import ConfigProvider
from yeying.api.asset import BlockMetadata, asset_pb2
from yeying.api.config import ConfigTypeEnum
from yeying.client.tool.crypto_service import AssetCipher
from yeying.client.utils import log_utils
from typing import Callable, TypedDict

log = log_utils.get_logger(__name__)


class Progress(TypedDict):
    """进度接口"""

    total: int
    completed: int


class DownloadResult(TypedDict):
    """上传结果接口"""

    block: BlockMetadata
    data: bytes
    progress: Progress


# 定义回调类型
DownloadCallback = Callable[[DownloadResult], None]

"""
资产仓库的客户端实现
文件下载
"""
class Downloader(object):

    def __init__(self, option: ProviderOption, algorithm: SecurityAlgorithm):
        # 数据块加密
        self.asset_cipher = AssetCipher(option.block_address, algorithm)
        # 资产元信息
        self.asset_provider = AssetProvider(option=option)
        # 文件操作
        self.block_provider = BlockProvider(option=option)
        # 字典配置
        self.config_provider = ConfigProvider(option=option)
        # 文件单个块的大小，从系统配置表中动态获取
        config_res = self.config_provider.get("chunk.size", ConfigTypeEnum.CONFIG_TYPE_SYSTEM)
        self.chunkSize = int(config_res.body.config.value)
        self.is_abort: bool = False

    def abort(self):
        self.is_abort = True

    def get(
        self,
        namespace_id: str,
        _hash: str,
        block_callback: DownloadCallback = None,
    ) -> asset_pb2.AssetMetadata:
        log.info("start download file")
        detail_res = self.asset_provider.detail(namespace_id, _hash)
        asset = detail_res.body.asset
        for i in range(asset.chunkCount):
            if self.is_abort:
                log.warn("download is abort")
                return asset_pb2.AssetMetadata()
            get_res = self.block_provider.get(namespace_id, asset.chunks[i])
            detail = BlockDetail(block=get_res.body.block, data=get_res.data)
            if asset.isEncrypted:
                # 如果资产加密，解密数据块
                detail.data = self.asset_cipher.decrypt(detail.data)
            if block_callback:
                result = DownloadResult(block=detail.block, data=detail.data, progress=Progress(total=asset.chunkCount, completed=i+1))
                block_callback(result)
        return asset

class BlockDetail(object):

    def __init__(self, block: BlockMetadata, data: bytes):
        self.block = block
        self.data = data


from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as _meta_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class DetailWarehouseRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DetailWarehouseRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DetailWarehouseRequestBody, _Mapping]] = ...,
    ) -> None: ...

class DetailWarehouseRequestBody(_message.Message):
    __slots__ = ("uid",)
    UID_FIELD_NUMBER: _ClassVar[int]
    uid: str
    def __init__(self, uid: _Optional[str] = ...) -> None: ...

class DetailWarehouseResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DetailWarehouseResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DetailWarehouseResponseBody, _Mapping]] = ...,
    ) -> None: ...

class DetailWarehouseResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _meta_pb2.WarehouseMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[_meta_pb2.WarehouseMetadata, _Mapping]] = ...,
    ) -> None: ...

class AddWarehouseRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AddWarehouseRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AddWarehouseRequestBody, _Mapping]] = ...,
    ) -> None: ...

class AddWarehouseRequestBody(_message.Message):
    __slots__ = ("meta",)
    META_FIELD_NUMBER: _ClassVar[int]
    meta: _meta_pb2.WarehouseMetadata
    def __init__(self, meta: _Optional[_Union[_meta_pb2.WarehouseMetadata, _Mapping]] = ...) -> None: ...

class AddWarehouseResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AddWarehouseResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AddWarehouseResponseBody, _Mapping]] = ...,
    ) -> None: ...

class AddWarehouseResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: _meta_pb2.WarehouseMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[_meta_pb2.WarehouseMetadata, _Mapping]] = ...,
    ) -> None: ...

class ListWarehouseRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ListWarehouseRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ListWarehouseRequestBody, _Mapping]] = ...,
    ) -> None: ...

class ListWarehouseRequestBody(_message.Message):
    __slots__ = ("did", "taskUid", "pageIndex", "pageSize")
    DID_FIELD_NUMBER: _ClassVar[int]
    TASKUID_FIELD_NUMBER: _ClassVar[int]
    PAGEINDEX_FIELD_NUMBER: _ClassVar[int]
    PAGESIZE_FIELD_NUMBER: _ClassVar[int]
    did: str
    taskUid: str
    pageIndex: _wrappers_pb2.Int32Value
    pageSize: _wrappers_pb2.Int32Value
    def __init__(
        self,
        did: _Optional[str] = ...,
        taskUid: _Optional[str] = ...,
        pageIndex: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ...,
        pageSize: _Optional[_Union[_wrappers_pb2.Int32Value, _Mapping]] = ...,
    ) -> None: ...

class ListWarehouseResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: ListWarehouseResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[ListWarehouseResponseBody, _Mapping]] = ...,
    ) -> None: ...

class ListWarehouseResponseBody(_message.Message):
    __slots__ = ("status", "list", "total")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    LIST_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    list: _containers.RepeatedCompositeFieldContainer[_meta_pb2.WarehouseMetadata]
    total: int
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        list: _Optional[_Iterable[_Union[_meta_pb2.WarehouseMetadata, _Mapping]]] = ...,
        total: _Optional[int] = ...,
    ) -> None: ...



# Generated by protobuf_init. Do not edit manually.
from .knowledge_pb2 import SearchRequest
from .knowledge_pb2 import SearchResponse
from .knowledge_pb2 import KnowledgeMetadata
from .knowledge_pb2 import AppendMetadata
from .knowledge_pb2 import AppendRequest
from .knowledge_pb2 import AppendResponse
from .knowledge_pb2 import ContentType
from .knowledge_pb2_grpc import KnowledgeServicer
from .knowledge_pb2_grpc import KnowledgeStub
from .knowledge_pb2_grpc import add_KnowledgeServicer_to_server
from .knowledge_pb2_grpc import Knowledge



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/apps/zuoyepigai/mistakes.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/apps/zuoyepigai/mistakes.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.apps.zuoyepigai import meta_pb2 as yeying_dot_api_dot_apps_dot_zuoyepigai_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n)yeying/api/apps/zuoyepigai/mistakes.proto\x12\x1ayeying.api.apps.zuoyepigai\x1a\x1fyeying/api/common/message.proto\x1a%yeying/api/apps/zuoyepigai/meta.proto"\x8a\x01\n\x13MistakesListRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x41\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x33.yeying.api.apps.zuoyepigai.MistakesListRequestBody"&\n\x17MistakesListRequestBody\x12\x0b\n\x03\x64id\x18\x01 \x01(\t"\x8c\x01\n\x14MistakesListResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.MistakesListResponseBody"\x89\x01\n\x18MistakesListResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12:\n\x04list\x18\x02 \x03(\x0b\x32,.yeying.api.apps.zuoyepigai.MistakesMetadata"\x8e\x01\n\x15MistakesDetailRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.MistakesDetailRequestBody"(\n\x19MistakesDetailRequestBody\x12\x0b\n\x03uid\x18\x01 \x01(\t"\x90\x01\n\x16MistakesDetailResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x44\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x36.yeying.api.apps.zuoyepigai.MistakesDetailResponseBody"\x8b\x01\n\x1aMistakesDetailResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12:\n\x04meta\x18\x02 \x01(\x0b\x32,.yeying.api.apps.zuoyepigai.MistakesMetadata"\x92\x01\n\x17MistakesAnalysisRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x45\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x37.yeying.api.apps.zuoyepigai.MistakesAnalysisRequestBody")\n\x1bMistakesAnalysisRequestBody\x12\n\n\x02qa\x18\x01 \x01(\t"\x94\x01\n\x18MistakesAnalysisResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x46\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x38.yeying.api.apps.zuoyepigai.MistakesAnalysisResponseBody"Q\n\x1cMistakesAnalysisResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x8e\x01\n\x15MakeCorrectionRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.MakeCorrectionRequestBody"\'\n\x19MakeCorrectionRequestBody\x12\n\n\x02qa\x18\x01 \x01(\t"\x90\x01\n\x16MakeCorrectionResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x44\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x36.yeying.api.apps.zuoyepigai.MakeCorrectionResponseBody"O\n\x1aMakeCorrectionResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x8c\x01\n\x14MistakesPrintRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x42\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x34.yeying.api.apps.zuoyepigai.MistakesPrintRequestBody"&\n\x18MistakesPrintRequestBody\x12\n\n\x02qa\x18\x01 \x01(\t"\x8e\x01\n\x15MistakesPrintResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.MistakesPrintResponseBody"N\n\x19MistakesPrintResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x8e\x01\n\x15MistakesSubmitRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x43\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x35.yeying.api.apps.zuoyepigai.MistakesSubmitRequestBody"\'\n\x19MistakesSubmitRequestBody\x12\n\n\x02qa\x18\x01 \x01(\t"\x90\x01\n\x16MistakesSubmitResponse\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x44\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x36.yeying.api.apps.zuoyepigai.MistakesSubmitResponseBody"O\n\x1aMistakesSubmitResponseBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus2\xc1\x05\n\x08Mistakes\x12k\n\x04List\x12/.yeying.api.apps.zuoyepigai.MistakesListRequest\x1a\x30.yeying.api.apps.zuoyepigai.MistakesListResponse"\x00\x12q\n\x06\x44\x65tail\x12\x31.yeying.api.apps.zuoyepigai.MistakesDetailRequest\x1a\x32.yeying.api.apps.zuoyepigai.MistakesDetailResponse"\x00\x12w\n\x08\x41nalysis\x12\x33.yeying.api.apps.zuoyepigai.MistakesAnalysisRequest\x1a\x34.yeying.api.apps.zuoyepigai.MistakesAnalysisResponse"\x00\x12y\n\x0eMakeCorrection\x12\x31.yeying.api.apps.zuoyepigai.MakeCorrectionRequest\x1a\x32.yeying.api.apps.zuoyepigai.MakeCorrectionResponse"\x00\x12n\n\x05Print\x12\x30.yeying.api.apps.zuoyepigai.MistakesPrintRequest\x1a\x31.yeying.api.apps.zuoyepigai.MistakesPrintResponse"\x00\x12q\n\x06Submit\x12\x31.yeying.api.apps.zuoyepigai.MistakesSubmitRequest\x1a\x32.yeying.api.apps.zuoyepigai.MistakesSubmitResponse"\x00\x42\x1cZ\x1ayeying/api/apps/zuoyepigaib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.apps.zuoyepigai.mistakes_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\032yeying/api/apps/zuoyepigai"
    _globals["_MISTAKESLISTREQUEST"]._serialized_start = 146
    _globals["_MISTAKESLISTREQUEST"]._serialized_end = 284
    _globals["_MISTAKESLISTREQUESTBODY"]._serialized_start = 286
    _globals["_MISTAKESLISTREQUESTBODY"]._serialized_end = 324
    _globals["_MISTAKESLISTRESPONSE"]._serialized_start = 327
    _globals["_MISTAKESLISTRESPONSE"]._serialized_end = 467
    _globals["_MISTAKESLISTRESPONSEBODY"]._serialized_start = 470
    _globals["_MISTAKESLISTRESPONSEBODY"]._serialized_end = 607
    _globals["_MISTAKESDETAILREQUEST"]._serialized_start = 610
    _globals["_MISTAKESDETAILREQUEST"]._serialized_end = 752
    _globals["_MISTAKESDETAILREQUESTBODY"]._serialized_start = 754
    _globals["_MISTAKESDETAILREQUESTBODY"]._serialized_end = 794
    _globals["_MISTAKESDETAILRESPONSE"]._serialized_start = 797
    _globals["_MISTAKESDETAILRESPONSE"]._serialized_end = 941
    _globals["_MISTAKESDETAILRESPONSEBODY"]._serialized_start = 944
    _globals["_MISTAKESDETAILRESPONSEBODY"]._serialized_end = 1083
    _globals["_MISTAKESANALYSISREQUEST"]._serialized_start = 1086
    _globals["_MISTAKESANALYSISREQUEST"]._serialized_end = 1232
    _globals["_MISTAKESANALYSISREQUESTBODY"]._serialized_start = 1234
    _globals["_MISTAKESANALYSISREQUESTBODY"]._serialized_end = 1275
    _globals["_MISTAKESANALYSISRESPONSE"]._serialized_start = 1278
    _globals["_MISTAKESANALYSISRESPONSE"]._serialized_end = 1426
    _globals["_MISTAKESANALYSISRESPONSEBODY"]._serialized_start = 1428
    _globals["_MISTAKESANALYSISRESPONSEBODY"]._serialized_end = 1509
    _globals["_MAKECORRECTIONREQUEST"]._serialized_start = 1512
    _globals["_MAKECORRECTIONREQUEST"]._serialized_end = 1654
    _globals["_MAKECORRECTIONREQUESTBODY"]._serialized_start = 1656
    _globals["_MAKECORRECTIONREQUESTBODY"]._serialized_end = 1695
    _globals["_MAKECORRECTIONRESPONSE"]._serialized_start = 1698
    _globals["_MAKECORRECTIONRESPONSE"]._serialized_end = 1842
    _globals["_MAKECORRECTIONRESPONSEBODY"]._serialized_start = 1844
    _globals["_MAKECORRECTIONRESPONSEBODY"]._serialized_end = 1923
    _globals["_MISTAKESPRINTREQUEST"]._serialized_start = 1926
    _globals["_MISTAKESPRINTREQUEST"]._serialized_end = 2066
    _globals["_MISTAKESPRINTREQUESTBODY"]._serialized_start = 2068
    _globals["_MISTAKESPRINTREQUESTBODY"]._serialized_end = 2106
    _globals["_MISTAKESPRINTRESPONSE"]._serialized_start = 2109
    _globals["_MISTAKESPRINTRESPONSE"]._serialized_end = 2251
    _globals["_MISTAKESPRINTRESPONSEBODY"]._serialized_start = 2253
    _globals["_MISTAKESPRINTRESPONSEBODY"]._serialized_end = 2331
    _globals["_MISTAKESSUBMITREQUEST"]._serialized_start = 2334
    _globals["_MISTAKESSUBMITREQUEST"]._serialized_end = 2476
    _globals["_MISTAKESSUBMITREQUESTBODY"]._serialized_start = 2478
    _globals["_MISTAKESSUBMITREQUESTBODY"]._serialized_end = 2517
    _globals["_MISTAKESSUBMITRESPONSE"]._serialized_start = 2520
    _globals["_MISTAKESSUBMITRESPONSE"]._serialized_end = 2664
    _globals["_MISTAKESSUBMITRESPONSEBODY"]._serialized_start = 2666
    _globals["_MISTAKESSUBMITRESPONSEBODY"]._serialized_end = 2745
    _globals["_MISTAKES"]._serialized_start = 2748
    _globals["_MISTAKES"]._serialized_end = 3453
# @@protoc_insertion_point(module_scope)



# Generated by protobuf_init. Do not edit manually.
from .prompt_pb2_grpc import PromptServicer
from .prompt_pb2_grpc import PromptStub
from .prompt_pb2_grpc import add_PromptServicer_to_server
from .prompt_pb2_grpc import Prompt
from .resource_pb2_grpc import ResourceServicer
from .resource_pb2_grpc import ResourceStub
from .resource_pb2_grpc import add_ResourceServicer_to_server
from .resource_pb2_grpc import Resource
from .tool_pb2_grpc import ToolServicer
from .tool_pb2_grpc import ToolStub
from .tool_pb2_grpc import add_ToolServicer_to_server
from .tool_pb2_grpc import Tool



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class ImageContentTypeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    QUESTION: _ClassVar[ImageContentTypeEnum]
    ANSWER: _ClassVar[ImageContentTypeEnum]
    QA: _ClassVar[ImageContentTypeEnum]

class TaskStatusEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CREATED: _ClassVar[TaskStatusEnum]
    WAIT_MARKING: _ClassVar[TaskStatusEnum]
    MARKING: _ClassVar[TaskStatusEnum]
    FINISH_MARKING: _ClassVar[TaskStatusEnum]
    WAIT_REVISE: _ClassVar[TaskStatusEnum]
    REVISE: _ClassVar[TaskStatusEnum]
    FINISH_REVISE: _ClassVar[TaskStatusEnum]

QUESTION: ImageContentTypeEnum
ANSWER: ImageContentTypeEnum
QA: ImageContentTypeEnum
CREATED: TaskStatusEnum
WAIT_MARKING: TaskStatusEnum
MARKING: TaskStatusEnum
FINISH_MARKING: TaskStatusEnum
WAIT_REVISE: TaskStatusEnum
REVISE: TaskStatusEnum
FINISH_REVISE: TaskStatusEnum



def sort_keys(json):
    """
    排序JSON数据的函数，包括其嵌套的对象和数组, 默认会移除值为None的健
    """
    if isinstance(json, dict):
        # 对字典类型进行排序，以及递归排序其值，如果它们可迭代
        return {key: sort_keys(value) for key, value in sorted(json.items()) if value is not None}
    elif isinstance(json, list):
        # 对于列表，只需排序其中可能嵌套的项目
        return [sort_keys(item) for item in json]
    else:
        # 不是字典或列表，直接返回原始数据
        return json


def safe_get(d, *args):
    """
    安全地获取嵌套JSON对象中的值。
    :param d: 待查询的字典或JSON对象
    :param args: 键的列表，表示要查询的路径
    :return: 如果找到指定路径的值，则返回该值；否则，返回None
    """
    if d is None:
        return None

    if len(args) == 0:
        return None

    v = d
    for key in args:
        if key in v:
            v = v[key]
        else:
            return None
    return v


def concat(*args):
    """
    接受变长参数，将各种类型按顺序拼接成字符串，并编码成字节。
    """
    concatenated_string = "".join(map(str, args))
    return concatenated_string.encode()


def composite(*byte_arrays):
    """
    将多个字节数组拼接成一个新的字节数组。
    """
    return b"".join(byte_arrays)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class ResponseCodeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    RESPONSE_CODE_UNKNOWN: _ClassVar[ResponseCodeEnum]
    OK: _ClassVar[ResponseCodeEnum]
    INVALID_ARGUMENT: _ClassVar[ResponseCodeEnum]
    UNAUTHENTICATED: _ClassVar[ResponseCodeEnum]
    PERMISSION_DENIED: _ClassVar[ResponseCodeEnum]
    NOT_FOUND: _ClassVar[ResponseCodeEnum]
    ALREADY_EXISTS: _ClassVar[ResponseCodeEnum]
    LIMIT_EXCEEDED: _ClassVar[ResponseCodeEnum]
    UNAVAILABLE: _ClassVar[ResponseCodeEnum]
    UNKNOWN_ERROR: _ClassVar[ResponseCodeEnum]
    NETWORK_ERROR: _ClassVar[ResponseCodeEnum]
    INVALID_CERT: _ClassVar[ResponseCodeEnum]
    NOT_SUPPORTED: _ClassVar[ResponseCodeEnum]
    DATA_CORRUPTED: _ClassVar[ResponseCodeEnum]

class ContractStatusEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CONTRACT_STATUS_UNKNOWN: _ClassVar[ContractStatusEnum]
    CONTRACT_STATUS_INACTIVATED: _ClassVar[ContractStatusEnum]
    CONTRACT_STATUS_ACTIVATED: _ClassVar[ContractStatusEnum]
    CONTRACT_STATUS_EXPIRED: _ClassVar[ContractStatusEnum]
    CONTRACT_STATUS_CANCELED: _ClassVar[ContractStatusEnum]

class LanguageCodeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    LANGUAGE_CODE_UNKNOWN: _ClassVar[LanguageCodeEnum]
    LANGUAGE_CODE_ZH_CH: _ClassVar[LanguageCodeEnum]
    LANGUAGE_CODE_EN_US: _ClassVar[LanguageCodeEnum]

class ApplicationCodeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    APPLICATION_CODE_UNKNOWN: _ClassVar[ApplicationCodeEnum]
    APPLICATION_CODE_MARKET: _ClassVar[ApplicationCodeEnum]
    APPLICATION_CODE_ASSET: _ClassVar[ApplicationCodeEnum]
    APPLICATION_CODE_KNOWLEDGE: _ClassVar[ApplicationCodeEnum]
    APPLICATION_CODE_KEEPER: _ClassVar[ApplicationCodeEnum]
    APPLICATION_CODE_SOCIAL: _ClassVar[ApplicationCodeEnum]
    APPLICATION_CODE_WORKBENCH: _ClassVar[ApplicationCodeEnum]

class ServiceCodeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SERVICE_CODE_UNKNOWN: _ClassVar[ServiceCodeEnum]
    SERVICE_CODE_NODE: _ClassVar[ServiceCodeEnum]
    SERVICE_CODE_WAREHOUSE: _ClassVar[ServiceCodeEnum]
    SERVICE_CODE_AGENT: _ClassVar[ServiceCodeEnum]
    SERVICE_CODE_MCP: _ClassVar[ServiceCodeEnum]
    SERVICE_CODE_AI: _ClassVar[ServiceCodeEnum]

class ApiCodeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    API_CODE_UNKNOWN: _ClassVar[ApiCodeEnum]
    API_CODE_USER: _ClassVar[ApiCodeEnum]
    API_CODE_IDENTITY: _ClassVar[ApiCodeEnum]
    API_CODE_LLM_SERVICE: _ClassVar[ApiCodeEnum]
    API_CODE_LLM_PROVIDER: _ClassVar[ApiCodeEnum]
    API_CODE_ASSET_SERVICE: _ClassVar[ApiCodeEnum]
    API_CODE_ASSET_BLOCK: _ClassVar[ApiCodeEnum]
    API_CODE_ASSET_LINK: _ClassVar[ApiCodeEnum]
    API_CODE_ASSET_NAMESPACE: _ClassVar[ApiCodeEnum]
    API_CODE_ASSET_RECYCLE: _ClassVar[ApiCodeEnum]
    API_CODE_CERTIFICATE: _ClassVar[ApiCodeEnum]
    API_CODE_STORAGE: _ClassVar[ApiCodeEnum]
    API_CODE_APPLICATION: _ClassVar[ApiCodeEnum]
    API_CODE_EVENT: _ClassVar[ApiCodeEnum]
    API_CODE_INVITATION: _ClassVar[ApiCodeEnum]
    API_CODE_SERVICE: _ClassVar[ApiCodeEnum]

class ImageFormatEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    IMAGE_FORMAT_UNKNOWN: _ClassVar[ImageFormatEnum]
    IMAGE_FORMAT_PNG: _ClassVar[ImageFormatEnum]

class DigitalFormatEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DIGITAL_FORMAT_UNKNOWN: _ClassVar[DigitalFormatEnum]
    DIGITAL_FORMAT_TEXT: _ClassVar[DigitalFormatEnum]
    DIGITAL_FORMAT_IMAGE: _ClassVar[DigitalFormatEnum]
    DIGITAL_FORMAT_VIDEO: _ClassVar[DigitalFormatEnum]
    DIGITAL_FORMAT_AUDIO: _ClassVar[DigitalFormatEnum]
    DIGITAL_FORMAT_APP: _ClassVar[DigitalFormatEnum]
    DIGITAL_FORMAT_OTHER: _ClassVar[DigitalFormatEnum]

class ContentFormatEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CONTENT_FORMAT_UNKNOWN: _ClassVar[ContentFormatEnum]
    CONTENT_FORMAT_URL: _ClassVar[ContentFormatEnum]
    CONTENT_FORMAT_BASE64: _ClassVar[ContentFormatEnum]

class SessionSceneEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SESSION_SCENE_UNKNOWN: _ClassVar[SessionSceneEnum]
    SESSION_SCENE_DIALOGUE: _ClassVar[SessionSceneEnum]
    SESSION_SCENE_DRAWING: _ClassVar[SessionSceneEnum]
    SESSION_SCENE_TRANSLATION: _ClassVar[SessionSceneEnum]

class SessionRoleEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SESSION_ROLE_UNKNOWN: _ClassVar[SessionRoleEnum]
    SESSION_ROLE_PARTICIPANT: _ClassVar[SessionRoleEnum]
    SESSION_ROLE_ADMIN: _ClassVar[SessionRoleEnum]

class ParticipantTypeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PARTICIPANT_TYPE_UNKNOWN: _ClassVar[ParticipantTypeEnum]
    PARTICIPANT_TYPE_SERVICE: _ClassVar[ParticipantTypeEnum]
    PARTICIPANT_TYPE_PEOPLE: _ClassVar[ParticipantTypeEnum]

class AuditTypeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    AUDIT_TYPE_APPLICATION: _ClassVar[AuditTypeEnum]
    AUDIT_TYPE_SERVICE: _ClassVar[AuditTypeEnum]
    AUDIT_TYPE_UNKNOWN: _ClassVar[AuditTypeEnum]

class ApplicationStatusEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    APPLICATION_STATUS_UNKNOWN: _ClassVar[ApplicationStatusEnum]
    APPLICATION_STATUS_CREATED: _ClassVar[ApplicationStatusEnum]
    APPLICATION_STATUS_AUDITED: _ClassVar[ApplicationStatusEnum]
    APPLICATION_STATUS_REFUSED: _ClassVar[ApplicationStatusEnum]
    APPLICATION_STATUS_OFFLINE: _ClassVar[ApplicationStatusEnum]
    APPLICATION_STATUS_ONLINE: _ClassVar[ApplicationStatusEnum]

class CipherTypeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CIPHER_TYPE_UNKNOWN: _ClassVar[CipherTypeEnum]
    CIPHER_TYPE_AES_GCM_256: _ClassVar[CipherTypeEnum]

class AuthenticateTypeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    AUTHENTICATE_TYPE_UNKNOWN: _ClassVar[AuthenticateTypeEnum]
    AUTHENTICATE_TYPE_CERT: _ClassVar[AuthenticateTypeEnum]
    AUTHENTICATE_TYPE_TOKEN: _ClassVar[AuthenticateTypeEnum]

RESPONSE_CODE_UNKNOWN: ResponseCodeEnum
OK: ResponseCodeEnum
INVALID_ARGUMENT: ResponseCodeEnum
UNAUTHENTICATED: ResponseCodeEnum
PERMISSION_DENIED: ResponseCodeEnum
NOT_FOUND: ResponseCodeEnum
ALREADY_EXISTS: ResponseCodeEnum
LIMIT_EXCEEDED: ResponseCodeEnum
UNAVAILABLE: ResponseCodeEnum
UNKNOWN_ERROR: ResponseCodeEnum
NETWORK_ERROR: ResponseCodeEnum
INVALID_CERT: ResponseCodeEnum
NOT_SUPPORTED: ResponseCodeEnum
DATA_CORRUPTED: ResponseCodeEnum
CONTRACT_STATUS_UNKNOWN: ContractStatusEnum
CONTRACT_STATUS_INACTIVATED: ContractStatusEnum
CONTRACT_STATUS_ACTIVATED: ContractStatusEnum
CONTRACT_STATUS_EXPIRED: ContractStatusEnum
CONTRACT_STATUS_CANCELED: ContractStatusEnum
LANGUAGE_CODE_UNKNOWN: LanguageCodeEnum
LANGUAGE_CODE_ZH_CH: LanguageCodeEnum
LANGUAGE_CODE_EN_US: LanguageCodeEnum
APPLICATION_CODE_UNKNOWN: ApplicationCodeEnum
APPLICATION_CODE_MARKET: ApplicationCodeEnum
APPLICATION_CODE_ASSET: ApplicationCodeEnum
APPLICATION_CODE_KNOWLEDGE: ApplicationCodeEnum
APPLICATION_CODE_KEEPER: ApplicationCodeEnum
APPLICATION_CODE_SOCIAL: ApplicationCodeEnum
APPLICATION_CODE_WORKBENCH: ApplicationCodeEnum
SERVICE_CODE_UNKNOWN: ServiceCodeEnum
SERVICE_CODE_NODE: ServiceCodeEnum
SERVICE_CODE_WAREHOUSE: ServiceCodeEnum
SERVICE_CODE_AGENT: ServiceCodeEnum
SERVICE_CODE_MCP: ServiceCodeEnum
SERVICE_CODE_AI: ServiceCodeEnum
API_CODE_UNKNOWN: ApiCodeEnum
API_CODE_USER: ApiCodeEnum
API_CODE_IDENTITY: ApiCodeEnum
API_CODE_LLM_SERVICE: ApiCodeEnum
API_CODE_LLM_PROVIDER: ApiCodeEnum
API_CODE_ASSET_SERVICE: ApiCodeEnum
API_CODE_ASSET_BLOCK: ApiCodeEnum
API_CODE_ASSET_LINK: ApiCodeEnum
API_CODE_ASSET_NAMESPACE: ApiCodeEnum
API_CODE_ASSET_RECYCLE: ApiCodeEnum
API_CODE_CERTIFICATE: ApiCodeEnum
API_CODE_STORAGE: ApiCodeEnum
API_CODE_APPLICATION: ApiCodeEnum
API_CODE_EVENT: ApiCodeEnum
API_CODE_INVITATION: ApiCodeEnum
API_CODE_SERVICE: ApiCodeEnum
IMAGE_FORMAT_UNKNOWN: ImageFormatEnum
IMAGE_FORMAT_PNG: ImageFormatEnum
DIGITAL_FORMAT_UNKNOWN: DigitalFormatEnum
DIGITAL_FORMAT_TEXT: DigitalFormatEnum
DIGITAL_FORMAT_IMAGE: DigitalFormatEnum
DIGITAL_FORMAT_VIDEO: DigitalFormatEnum
DIGITAL_FORMAT_AUDIO: DigitalFormatEnum
DIGITAL_FORMAT_APP: DigitalFormatEnum
DIGITAL_FORMAT_OTHER: DigitalFormatEnum
CONTENT_FORMAT_UNKNOWN: ContentFormatEnum
CONTENT_FORMAT_URL: ContentFormatEnum
CONTENT_FORMAT_BASE64: ContentFormatEnum
SESSION_SCENE_UNKNOWN: SessionSceneEnum
SESSION_SCENE_DIALOGUE: SessionSceneEnum
SESSION_SCENE_DRAWING: SessionSceneEnum
SESSION_SCENE_TRANSLATION: SessionSceneEnum
SESSION_ROLE_UNKNOWN: SessionRoleEnum
SESSION_ROLE_PARTICIPANT: SessionRoleEnum
SESSION_ROLE_ADMIN: SessionRoleEnum
PARTICIPANT_TYPE_UNKNOWN: ParticipantTypeEnum
PARTICIPANT_TYPE_SERVICE: ParticipantTypeEnum
PARTICIPANT_TYPE_PEOPLE: ParticipantTypeEnum
AUDIT_TYPE_APPLICATION: AuditTypeEnum
AUDIT_TYPE_SERVICE: AuditTypeEnum
AUDIT_TYPE_UNKNOWN: AuditTypeEnum
APPLICATION_STATUS_UNKNOWN: ApplicationStatusEnum
APPLICATION_STATUS_CREATED: ApplicationStatusEnum
APPLICATION_STATUS_AUDITED: ApplicationStatusEnum
APPLICATION_STATUS_REFUSED: ApplicationStatusEnum
APPLICATION_STATUS_OFFLINE: ApplicationStatusEnum
APPLICATION_STATUS_ONLINE: ApplicationStatusEnum
CIPHER_TYPE_UNKNOWN: CipherTypeEnum
CIPHER_TYPE_AES_GCM_256: CipherTypeEnum
AUTHENTICATE_TYPE_UNKNOWN: AuthenticateTypeEnum
AUTHENTICATE_TYPE_CERT: AuthenticateTypeEnum
AUTHENTICATE_TYPE_TOKEN: AuthenticateTypeEnum



from yeying.api.common import message_pb2 as _message_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class UrlStatusEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    URL_STATUS_UNKNOWN: _ClassVar[UrlStatusEnum]
    URL_STATUS_ENABLE: _ClassVar[UrlStatusEnum]
    URL_STATUS_DISABLE: _ClassVar[UrlStatusEnum]

class LinkTypeEnum(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    LINK_TYPE_UNKNOWN: _ClassVar[LinkTypeEnum]
    LINK_TYPE_PUBLIC: _ClassVar[LinkTypeEnum]
    LINK_TYPE_AUTHENTICATED: _ClassVar[LinkTypeEnum]

URL_STATUS_UNKNOWN: UrlStatusEnum
URL_STATUS_ENABLE: UrlStatusEnum
URL_STATUS_DISABLE: UrlStatusEnum
LINK_TYPE_UNKNOWN: LinkTypeEnum
LINK_TYPE_PUBLIC: LinkTypeEnum
LINK_TYPE_AUTHENTICATED: LinkTypeEnum

class CreateLinkRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CreateLinkRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CreateLinkRequestBody, _Mapping]] = ...,
    ) -> None: ...

class CreateLinkRequestBody(_message.Message):
    __slots__ = ("link",)
    LINK_FIELD_NUMBER: _ClassVar[int]
    link: LinkMetadata
    def __init__(self, link: _Optional[_Union[LinkMetadata, _Mapping]] = ...) -> None: ...

class CreateLinkResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CreateLinkResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CreateLinkResponseBody, _Mapping]] = ...,
    ) -> None: ...

class CreateLinkResponseBody(_message.Message):
    __slots__ = ("status", "detail")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    DETAIL_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    detail: LinkDetail
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        detail: _Optional[_Union[LinkDetail, _Mapping]] = ...,
    ) -> None: ...

class SearchLinkRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SearchLinkRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SearchLinkRequestBody, _Mapping]] = ...,
    ) -> None: ...

class SearchLinkRequestBody(_message.Message):
    __slots__ = ("page", "condition")
    PAGE_FIELD_NUMBER: _ClassVar[int]
    CONDITION_FIELD_NUMBER: _ClassVar[int]
    page: _message_pb2.RequestPage
    condition: SearchLinkCondition
    def __init__(
        self,
        page: _Optional[_Union[_message_pb2.RequestPage, _Mapping]] = ...,
        condition: _Optional[_Union[SearchLinkCondition, _Mapping]] = ...,
    ) -> None: ...

class SearchLinkCondition(_message.Message):
    __slots__ = ("hash",)
    HASH_FIELD_NUMBER: _ClassVar[int]
    hash: str
    def __init__(self, hash: _Optional[str] = ...) -> None: ...

class SearchLinkResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: SearchLinkResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[SearchLinkResponseBody, _Mapping]] = ...,
    ) -> None: ...

class SearchLinkResponseBody(_message.Message):
    __slots__ = ("status", "page", "links")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    LINKS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    page: _message_pb2.ResponsePage
    links: _containers.RepeatedCompositeFieldContainer[LinkMetadata]
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        page: _Optional[_Union[_message_pb2.ResponsePage, _Mapping]] = ...,
        links: _Optional[_Iterable[_Union[LinkMetadata, _Mapping]]] = ...,
    ) -> None: ...

class DisableLinkRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DisableLinkRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DisableLinkRequestBody, _Mapping]] = ...,
    ) -> None: ...

class DisableLinkRequestBody(_message.Message):
    __slots__ = ("linkId",)
    LINKID_FIELD_NUMBER: _ClassVar[int]
    linkId: str
    def __init__(self, linkId: _Optional[str] = ...) -> None: ...

class DisableLinkResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DisableLinkResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DisableLinkResponseBody, _Mapping]] = ...,
    ) -> None: ...

class DisableLinkResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class UpdateLinkRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UpdateLinkRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UpdateLinkRequestBody, _Mapping]] = ...,
    ) -> None: ...

class UpdateLinkRequestBody(_message.Message):
    __slots__ = ("link",)
    LINK_FIELD_NUMBER: _ClassVar[int]
    link: LinkMetadata
    def __init__(self, link: _Optional[_Union[LinkMetadata, _Mapping]] = ...) -> None: ...

class UpdateLinkResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UpdateLinkResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UpdateLinkResponseBody, _Mapping]] = ...,
    ) -> None: ...

class UpdateLinkResponseBody(_message.Message):
    __slots__ = ("status", "detail")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    DETAIL_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    detail: LinkDetail
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        detail: _Optional[_Union[LinkDetail, _Mapping]] = ...,
    ) -> None: ...

class LinkDetailRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: LinkDetailRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[LinkDetailRequestBody, _Mapping]] = ...,
    ) -> None: ...

class LinkDetailRequestBody(_message.Message):
    __slots__ = ("uid",)
    UID_FIELD_NUMBER: _ClassVar[int]
    uid: str
    def __init__(self, uid: _Optional[str] = ...) -> None: ...

class LinkDetailResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: LinkDetailResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[LinkDetailResponseBody, _Mapping]] = ...,
    ) -> None: ...

class LinkDetailResponseBody(_message.Message):
    __slots__ = ("status", "detail")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    DETAIL_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    detail: LinkDetail
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        detail: _Optional[_Union[LinkDetail, _Mapping]] = ...,
    ) -> None: ...

class LinkDetail(_message.Message):
    __slots__ = ("url", "link")
    URL_FIELD_NUMBER: _ClassVar[int]
    LINK_FIELD_NUMBER: _ClassVar[int]
    url: UrlMetadata
    link: LinkMetadata
    def __init__(
        self, url: _Optional[_Union[UrlMetadata, _Mapping]] = ..., link: _Optional[_Union[LinkMetadata, _Mapping]] = ...
    ) -> None: ...

class LinkVisitorRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: LinkVisitorRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[LinkVisitorRequestBody, _Mapping]] = ...,
    ) -> None: ...

class LinkVisitorRequestBody(_message.Message):
    __slots__ = ("uid", "page")
    UID_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    uid: str
    page: _message_pb2.RequestPage
    def __init__(
        self, uid: _Optional[str] = ..., page: _Optional[_Union[_message_pb2.RequestPage, _Mapping]] = ...
    ) -> None: ...

class LinkVisitorResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: LinkVisitorResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[LinkVisitorResponseBody, _Mapping]] = ...,
    ) -> None: ...

class LinkVisitorResponseBody(_message.Message):
    __slots__ = ("status", "page", "visitors")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    VISITORS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    page: _message_pb2.ResponsePage
    visitors: _containers.RepeatedCompositeFieldContainer[VisitorMetadata]
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        page: _Optional[_Union[_message_pb2.ResponsePage, _Mapping]] = ...,
        visitors: _Optional[_Iterable[_Union[VisitorMetadata, _Mapping]]] = ...,
    ) -> None: ...

class LinkMetadata(_message.Message):
    __slots__ = (
        "owner",
        "uid",
        "type",
        "visitors",
        "namespaceId",
        "name",
        "description",
        "hash",
        "token",
        "startedAt",
        "expiredAt",
        "createdAt",
        "signature",
    )
    OWNER_FIELD_NUMBER: _ClassVar[int]
    UID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VISITORS_FIELD_NUMBER: _ClassVar[int]
    NAMESPACEID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    STARTEDAT_FIELD_NUMBER: _ClassVar[int]
    EXPIREDAT_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    owner: str
    uid: str
    type: LinkTypeEnum
    visitors: str
    namespaceId: str
    name: str
    description: str
    hash: str
    token: str
    startedAt: str
    expiredAt: str
    createdAt: str
    signature: str
    def __init__(
        self,
        owner: _Optional[str] = ...,
        uid: _Optional[str] = ...,
        type: _Optional[_Union[LinkTypeEnum, str]] = ...,
        visitors: _Optional[str] = ...,
        namespaceId: _Optional[str] = ...,
        name: _Optional[str] = ...,
        description: _Optional[str] = ...,
        hash: _Optional[str] = ...,
        token: _Optional[str] = ...,
        startedAt: _Optional[str] = ...,
        expiredAt: _Optional[str] = ...,
        createdAt: _Optional[str] = ...,
        signature: _Optional[str] = ...,
    ) -> None: ...

class UrlMetadata(_message.Message):
    __slots__ = ("serviceDid", "linkId", "token", "url", "status", "createdAt", "updatedAt", "signature")
    SERVICEDID_FIELD_NUMBER: _ClassVar[int]
    LINKID_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    serviceDid: str
    linkId: str
    token: str
    url: str
    status: UrlStatusEnum
    createdAt: str
    updatedAt: str
    signature: str
    def __init__(
        self,
        serviceDid: _Optional[str] = ...,
        linkId: _Optional[str] = ...,
        token: _Optional[str] = ...,
        url: _Optional[str] = ...,
        status: _Optional[_Union[UrlStatusEnum, str]] = ...,
        createdAt: _Optional[str] = ...,
        updatedAt: _Optional[str] = ...,
        signature: _Optional[str] = ...,
    ) -> None: ...

class VisitorMetadata(_message.Message):
    __slots__ = ("linkId", "did", "createdAt", "signature")
    LINKID_FIELD_NUMBER: _ClassVar[int]
    DID_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    linkId: str
    did: str
    createdAt: str
    signature: str
    def __init__(
        self,
        linkId: _Optional[str] = ...,
        did: _Optional[str] = ...,
        createdAt: _Optional[str] = ...,
        signature: _Optional[str] = ...,
    ) -> None: ...



# Generated by protobuf_init. Do not edit manually.
from .web3_pb2 import Identity
from .web3_pb2 import Registry
from .web3_pb2 import IdentityMetadata
from .web3_pb2 import BlockAddress
from .web3_pb2 import Mnemonic
from .web3_pb2 import IdentityServiceExtend
from .web3_pb2 import IdentityOrganizationExtend
from .web3_pb2 import IdentityPersonalExtend
from .web3_pb2 import IdentityApplicationExtend
from .web3_pb2 import SecurityConfig
from .web3_pb2 import SecurityAlgorithm
from .web3_pb2 import IdentityCodeEnum
from .web3_pb2 import NetworkTypeEnum



# Generated by protobuf_init. Do not edit manually.
from .application_pb2 import SearchApplicationRequest
from .application_pb2 import SearchApplicationRequestBody
from .application_pb2 import SearchCondition
from .application_pb2 import SearchApplicationResponse
from .application_pb2 import SearchApplicationResponseBody
from .application_pb2 import CreateApplicationRequest
from .application_pb2 import CreateApplicationRequestBody
from .application_pb2 import CreateApplicationResponse
from .application_pb2 import CreateApplicationResponseBody
from .application_pb2 import ApplicationDetailRequest
from .application_pb2 import ApplicationDetailRequestBody
from .application_pb2 import ApplicationDetailResponse
from .application_pb2 import ApplicationDetailResponseBody
from .application_pb2 import OfflineApplicationRequest
from .application_pb2 import OfflineApplicationRequestBody
from .application_pb2 import OfflineApplicationResponse
from .application_pb2 import OfflineApplicationResponseBody
from .application_pb2 import OnlineApplicationRequest
from .application_pb2 import OnlineApplicationRequestBody
from .application_pb2 import OnlineApplicationResponse
from .application_pb2 import OnlineApplicationResponseBody
from .application_pb2 import ApplicationExtend
from .application_pb2 import ApplicationComment
from .application_pb2 import DeleteApplicationRequest
from .application_pb2 import DeleteApplicationRequestBody
from .application_pb2 import DeleteApplicationResponse
from .application_pb2 import DeleteApplicationResponseBody
from .application_pb2 import AuditApplicationRequest
from .application_pb2 import AuditApplicationRequestBody
from .application_pb2 import AuditApplicationResponse
from .application_pb2 import AuditApplicationResponseBody
from .application_pb2_grpc import ApplicationServicer
from .application_pb2_grpc import ApplicationStub
from .application_pb2_grpc import add_ApplicationServicer_to_server
from .application_pb2_grpc import Application



# -*- coding:utf-8 -*-
import uuid

from google.protobuf.json_format import MessageToJson

from yeying.client.provider.config_provider import ConfigProvider
from yeying.client.utils.date_utils import get_current_utc_string

from yeying.api.asset import namespace_pb2_grpc, namespace_pb2, SearchNamespaceCondition
from yeying.api.common import ResponseCodeEnum, message_pb2
from yeying.client.provider.base_provider import BaseProvider
from yeying.api.config import config_pb2
import grpc
from yeying.client.utils import log_utils

log = log_utils.get_logger(__name__)


"""
资产仓库资源管理空间 CURD
"""


class NamespaceProvider(BaseProvider):

    def __init__(self, **kw):
        super(NamespaceProvider, self).__init__(**kw)
        # 资产元信息
        self.namespace_client = namespace_pb2_grpc.NamespaceStub(grpc.insecure_channel(self.option.proxy))
        # 字典配置
        self.config_provider = ConfigProvider(option=self.option)

    def get_default_namespace(self) -> str:
        config_res: config_pb2.GetConfigResponse = self.config_provider.get(key="namespace.default", config_type=config_pb2.ConfigTypeEnum.CONFIG_TYPE_USER)
        return config_res.body.config.value

    def set_default_namespace(self, namespace_id: str) -> config_pb2.SetConfigResponse:
        return self.config_provider.set(key="namespace.default", value=namespace_id)

    def search(self, page: int, page_size: int, condition: SearchNamespaceCondition) -> namespace_pb2.SearchNamespaceResponse:
        body = namespace_pb2.SearchNamespaceRequestBody(condition=condition, page=message_pb2.RequestPage(page=page, pageSize=page_size))
        header = self.authenticate.create_header(body=body)
        request = namespace_pb2.SearchNamespaceRequest(header=header, body=body)
        response: namespace_pb2.SearchNamespaceResponse = self.namespace_client.Search(request)

        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"search error, response={MessageToJson(response)}")
        return response

    def detail(
        self, uid: str
    ) -> namespace_pb2.NamespaceDetailResponse:
        if not uid:
            raise ValueError("uid is None")
        body = namespace_pb2.NamespaceDetailRequestBody(uid=uid)
        header = self.authenticate.create_header(body=body)
        request = namespace_pb2.NamespaceDetailRequest(header=header, body=body)
        response: namespace_pb2.NamespaceDetailResponse = self.namespace_client.Detail(request)

        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"detail error, response={MessageToJson(response)}")
        return response

    def delete(self, uid: str) -> namespace_pb2.DeleteNamespaceResponse:
        body = namespace_pb2.DeleteNamespaceRequestBody(uid=uid)
        header = self.authenticate.create_header(body=body)
        request = namespace_pb2.DeleteNamespaceRequest(header=header, body=body)
        response: namespace_pb2.DeleteNamespaceResponse = self.namespace_client.Delete(request)

        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"delete error, response={MessageToJson(response)}")
        return response

    def create(self, name: str, description: str, uid: str=None, participants: str=None) -> namespace_pb2.CreateNamespaceResponse:
        if not name:
            raise ValueError("name is None")
        namespace = namespace_pb2.NamespaceMetadata(
            owner=self.authenticate.get_did(),
            participants=participants,
            uid=uid if uid else str(uuid.uuid4()),
            name=name,
            description=description,
            createdAt=get_current_utc_string(),
            updatedAt=get_current_utc_string(),
        )
        namespace.signature = self.authenticate.sign_data(namespace.SerializeToString())
        body = namespace_pb2.CreateNamespaceRequestBody(
            namespace=namespace
        )

        header = self.authenticate.create_header(body=body)
        request = namespace_pb2.CreateNamespaceRequest(header=header, body=body)
        response: namespace_pb2.CreateNamespaceResponse = self.namespace_client.Create(request)

        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"create error, response={MessageToJson(response)}")
        return response


from yeying.api.common import message_pb2 as _message_pb2
from yeying.api.common import code_pb2 as _code_pb2
from yeying.api.common import model_pb2 as _model_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class AuditStatus(_message.Message):
    __slots__ = ("pending", "canceled", "passed", "reject")
    PENDING_FIELD_NUMBER: _ClassVar[int]
    CANCELED_FIELD_NUMBER: _ClassVar[int]
    PASSED_FIELD_NUMBER: _ClassVar[int]
    REJECT_FIELD_NUMBER: _ClassVar[int]
    pending: PendingStatus
    canceled: CanceledStatus
    passed: PassedStatus
    reject: RejectStatus
    def __init__(
        self,
        pending: _Optional[_Union[PendingStatus, _Mapping]] = ...,
        canceled: _Optional[_Union[CanceledStatus, _Mapping]] = ...,
        passed: _Optional[_Union[PassedStatus, _Mapping]] = ...,
        reject: _Optional[_Union[RejectStatus, _Mapping]] = ...,
    ) -> None: ...

class PendingStatus(_message.Message):
    __slots__ = ("text",)
    TEXT_FIELD_NUMBER: _ClassVar[int]
    text: str
    def __init__(self, text: _Optional[str] = ...) -> None: ...

class CanceledStatus(_message.Message):
    __slots__ = ("text",)
    TEXT_FIELD_NUMBER: _ClassVar[int]
    text: str
    def __init__(self, text: _Optional[str] = ...) -> None: ...

class PassedStatus(_message.Message):
    __slots__ = ("text",)
    TEXT_FIELD_NUMBER: _ClassVar[int]
    text: str
    def __init__(self, text: _Optional[str] = ...) -> None: ...

class RejectStatus(_message.Message):
    __slots__ = ("text",)
    TEXT_FIELD_NUMBER: _ClassVar[int]
    text: str
    def __init__(self, text: _Optional[str] = ...) -> None: ...

class CreateRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CreateRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CreateRequestBody, _Mapping]] = ...,
    ) -> None: ...

class CreateRequestBody(_message.Message):
    __slots__ = ("meta",)
    META_FIELD_NUMBER: _ClassVar[int]
    meta: AuditMetadata
    def __init__(self, meta: _Optional[_Union[AuditMetadata, _Mapping]] = ...) -> None: ...

class CreateResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CreateResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CreateResponseBody, _Mapping]] = ...,
    ) -> None: ...

class CreateResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: AuditMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[AuditMetadata, _Mapping]] = ...,
    ) -> None: ...

class DetailRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DetailRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DetailRequestBody, _Mapping]] = ...,
    ) -> None: ...

class DetailRequestBody(_message.Message):
    __slots__ = ("uid",)
    UID_FIELD_NUMBER: _ClassVar[int]
    uid: str
    def __init__(self, uid: _Optional[str] = ...) -> None: ...

class DetailResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: DetailResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[DetailResponseBody, _Mapping]] = ...,
    ) -> None: ...

class DetailResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: AuditMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[AuditMetadata, _Mapping]] = ...,
    ) -> None: ...

class CancelRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CancelRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CancelRequestBody, _Mapping]] = ...,
    ) -> None: ...

class CancelRequestBody(_message.Message):
    __slots__ = ("uid",)
    UID_FIELD_NUMBER: _ClassVar[int]
    uid: str
    def __init__(self, uid: _Optional[str] = ...) -> None: ...

class CancelResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CancelResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CancelResponseBody, _Mapping]] = ...,
    ) -> None: ...

class CancelResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: AuditMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[AuditMetadata, _Mapping]] = ...,
    ) -> None: ...

class UnbindRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UnbindRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UnbindRequestBody, _Mapping]] = ...,
    ) -> None: ...

class UnbindRequestBody(_message.Message):
    __slots__ = ("uid",)
    UID_FIELD_NUMBER: _ClassVar[int]
    uid: str
    def __init__(self, uid: _Optional[str] = ...) -> None: ...

class UnbindResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: UnbindResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[UnbindResponseBody, _Mapping]] = ...,
    ) -> None: ...

class UnbindResponseBody(_message.Message):
    __slots__ = ("status",)
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    def __init__(self, status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...) -> None: ...

class AuditRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AuditRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AuditRequestBody, _Mapping]] = ...,
    ) -> None: ...

class AuditRequestBody(_message.Message):
    __slots__ = ("uid", "status")
    UID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    uid: str
    status: AuditStatus
    def __init__(self, uid: _Optional[str] = ..., status: _Optional[_Union[AuditStatus, _Mapping]] = ...) -> None: ...

class AuditResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AuditResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AuditResponseBody, _Mapping]] = ...,
    ) -> None: ...

class AuditResponseBody(_message.Message):
    __slots__ = ("status", "meta")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    META_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    meta: AuditMetadata
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        meta: _Optional[_Union[AuditMetadata, _Mapping]] = ...,
    ) -> None: ...

class CreateAuditListRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CreateAuditListRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CreateAuditListRequestBody, _Mapping]] = ...,
    ) -> None: ...

class CreateAuditListRequestBody(_message.Message):
    __slots__ = ("condition", "page")
    CONDITION_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    condition: AuditSearchCondition
    page: _message_pb2.RequestPage
    def __init__(
        self,
        condition: _Optional[_Union[AuditSearchCondition, _Mapping]] = ...,
        page: _Optional[_Union[_message_pb2.RequestPage, _Mapping]] = ...,
    ) -> None: ...

class CreateAuditListResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: CreateAuditListResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[CreateAuditListResponseBody, _Mapping]] = ...,
    ) -> None: ...

class CreateAuditListResponseBody(_message.Message):
    __slots__ = ("status", "audits", "page")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    AUDITS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    audits: _containers.RepeatedCompositeFieldContainer[AuditMetadata]
    page: _message_pb2.ResponsePage
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        audits: _Optional[_Iterable[_Union[AuditMetadata, _Mapping]]] = ...,
        page: _Optional[_Union[_message_pb2.ResponsePage, _Mapping]] = ...,
    ) -> None: ...

class AuditListRequest(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AuditListRequestBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AuditListRequestBody, _Mapping]] = ...,
    ) -> None: ...

class AuditListRequestBody(_message.Message):
    __slots__ = ("condition", "page")
    CONDITION_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    condition: AuditSearchCondition
    page: _message_pb2.RequestPage
    def __init__(
        self,
        condition: _Optional[_Union[AuditSearchCondition, _Mapping]] = ...,
        page: _Optional[_Union[_message_pb2.RequestPage, _Mapping]] = ...,
    ) -> None: ...

class AuditListResponse(_message.Message):
    __slots__ = ("header", "body")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    header: _message_pb2.MessageHeader
    body: AuditListResponseBody
    def __init__(
        self,
        header: _Optional[_Union[_message_pb2.MessageHeader, _Mapping]] = ...,
        body: _Optional[_Union[AuditListResponseBody, _Mapping]] = ...,
    ) -> None: ...

class AuditListResponseBody(_message.Message):
    __slots__ = ("status", "audits", "page")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    AUDITS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    status: _message_pb2.ResponseStatus
    audits: _containers.RepeatedCompositeFieldContainer[AuditMetadata]
    page: _message_pb2.ResponsePage
    def __init__(
        self,
        status: _Optional[_Union[_message_pb2.ResponseStatus, _Mapping]] = ...,
        audits: _Optional[_Iterable[_Union[AuditMetadata, _Mapping]]] = ...,
        page: _Optional[_Union[_message_pb2.ResponsePage, _Mapping]] = ...,
    ) -> None: ...

class AuditSearchCondition(_message.Message):
    __slots__ = ("sourceDid", "name", "startTime", "endTime", "type", "targetDid")
    SOURCEDID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    STARTTIME_FIELD_NUMBER: _ClassVar[int]
    ENDTIME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    TARGETDID_FIELD_NUMBER: _ClassVar[int]
    sourceDid: str
    name: str
    startTime: str
    endTime: str
    type: _code_pb2.AuditTypeEnum
    targetDid: str
    def __init__(
        self,
        sourceDid: _Optional[str] = ...,
        name: _Optional[str] = ...,
        startTime: _Optional[str] = ...,
        endTime: _Optional[str] = ...,
        type: _Optional[_Union[_code_pb2.AuditTypeEnum, str]] = ...,
        targetDid: _Optional[str] = ...,
    ) -> None: ...

class AuditMetadata(_message.Message):
    __slots__ = (
        "uid",
        "appName",
        "sourceDid",
        "sourceName",
        "targetDid",
        "targetName",
        "reason",
        "status",
        "createdAt",
        "updatedAt",
        "type",
    )
    UID_FIELD_NUMBER: _ClassVar[int]
    APPNAME_FIELD_NUMBER: _ClassVar[int]
    SOURCEDID_FIELD_NUMBER: _ClassVar[int]
    SOURCENAME_FIELD_NUMBER: _ClassVar[int]
    TARGETDID_FIELD_NUMBER: _ClassVar[int]
    TARGETNAME_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATEDAT_FIELD_NUMBER: _ClassVar[int]
    UPDATEDAT_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    uid: str
    appName: str
    sourceDid: str
    sourceName: str
    targetDid: str
    targetName: str
    reason: str
    status: AuditStatus
    createdAt: str
    updatedAt: str
    type: _code_pb2.AuditTypeEnum
    def __init__(
        self,
        uid: _Optional[str] = ...,
        appName: _Optional[str] = ...,
        sourceDid: _Optional[str] = ...,
        sourceName: _Optional[str] = ...,
        targetDid: _Optional[str] = ...,
        targetName: _Optional[str] = ...,
        reason: _Optional[str] = ...,
        status: _Optional[_Union[AuditStatus, _Mapping]] = ...,
        createdAt: _Optional[str] = ...,
        updatedAt: _Optional[str] = ...,
        type: _Optional[_Union[_code_pb2.AuditTypeEnum, str]] = ...,
    ) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/llm/llm.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/llm/llm.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import message_pb2 as yeying_dot_api_dot_common_dot_message__pb2
from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x18yeying/api/llm/llm.proto\x12\x0eyeying.api.llm\x1a\x1fyeying/api/common/message.proto\x1a\x1cyeying/api/common/code.proto"v\n\x0f\x43ompleteRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.llm.CompleteRequestBody"\x98\x01\n\x13\x43ompleteRequestBody\x12\x11\n\tsessionId\x18\x01 \x01(\t\x12\x10\n\x08promptId\x18\x02 \x01(\t\x12\x12\n\nproviderId\x18\x03 \x01(\t\x12\r\n\x05model\x18\x04 \x01(\t\x12\x0e\n\x06stream\x18\x05 \x01(\x08\x12)\n\x08messages\x18\x06 \x03(\x0b\x32\x17.yeying.api.llm.Message"b\n\x07Message\x12-\n\x04role\x18\x01 \x01(\x0e\x32\x1f.yeying.api.llm.MessageRoleEnum\x12(\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x17.yeying.api.llm.Content"F\n\x07\x43ontent\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.yeying.api.llm.ContentTypeEnum\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t"_\n\x06\x41nswer\x12\r\n\x05model\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x11\n\tcreatedAt\x18\x03 \x01(\x03\x12\'\n\x07\x63hoices\x18\x04 \x03(\x0b\x32\x16.yeying.api.llm.Choice"\xbc\x01\n\x10\x43ompleteResponse\x12\x34\n\x04head\x18\x02 \x01(\x0b\x32$.yeying.api.llm.CompleteResponseHeadH\x00\x12\x34\n\x04\x62ody\x18\x03 \x01(\x0b\x32$.yeying.api.llm.CompleteResponseBodyH\x00\x12\x34\n\x04tail\x18\x04 \x01(\x0b\x32$.yeying.api.llm.CompleteResponseTailH\x00\x42\x06\n\x04\x64\x61ta"\x80\x01\n\x14\x43ompleteResponseHead\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.llm.CompleteResponseHeadBody"M\n\x18\x43ompleteResponseHeadBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"$\n\x14\x43ompleteResponseBody\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t"\x80\x01\n\x14\x43ompleteResponseTail\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.llm.CompleteResponseTailBody"M\n\x18\x43ompleteResponseTailBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"v\n\x0fGenerateRequest\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x31\n\x04\x62ody\x18\x02 \x01(\x0b\x32#.yeying.api.llm.GenerateRequestBody"\xc5\x01\n\x13GenerateRequestBody\x12\r\n\x05llmId\x18\x01 \x01(\t\x12\r\n\x05model\x18\x02 \x01(\t\x12\x0e\n\x06prompt\x18\x03 \x01(\t\x12\x43\n\x15responseContentFormat\x18\x04 \x01(\x0e\x32$.yeying.api.common.ContentFormatEnum\x12\r\n\x05\x63ount\x18\x05 \x01(\x05\x12\x0c\n\x04size\x18\x06 \x01(\t\x12\x0f\n\x07quality\x18\x07 \x01(\t\x12\r\n\x05style\x18\x08 \x01(\t"\xbc\x01\n\x10GenerateResponse\x12\x34\n\x04head\x18\x02 \x01(\x0b\x32$.yeying.api.llm.GenerateResponseHeadH\x00\x12\x34\n\x04\x62ody\x18\x03 \x01(\x0b\x32$.yeying.api.llm.GenerateResponseBodyH\x00\x12\x34\n\x04tail\x18\x04 \x01(\x0b\x32$.yeying.api.llm.GenerateResponseTailH\x00\x42\x06\n\x04\x64\x61ta"\x80\x01\n\x14GenerateResponseHead\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.llm.GenerateResponseHeadBody"M\n\x18GenerateResponseHeadBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"$\n\x14GenerateResponseBody\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t"\x80\x01\n\x14GenerateResponseTail\x12\x30\n\x06header\x18\x01 \x01(\x0b\x32 .yeying.api.common.MessageHeader\x12\x36\n\x04\x62ody\x18\x02 \x01(\x0b\x32(.yeying.api.llm.GenerateResponseTailBody"M\n\x18GenerateResponseTailBody\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x1d\n\nTextPrompt\x12\x0f\n\x07message\x18\x01 \x01(\t";\n\x0bImagePrompt\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04mask\x18\x02 \x01(\x0c\x12\r\n\x05image\x18\x03 \x01(\x0c"\x8f\x01\n\x0bImageResult\x12\x43\n\x15responseContentFormat\x18\x01 \x01(\x0e\x32$.yeying.api.common.ContentFormatEnum\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x0c\n\x04size\x18\x03 \x01(\t\x12\x0f\n\x07quality\x18\x04 \x01(\t\x12\r\n\x05style\x18\x05 \x01(\t"\xd4\x02\n\x0b\x45\x64itRequest\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\r\n\x05llmId\x18\x02 \x01(\t\x12\r\n\x05model\x18\x03 \x01(\t\x12\x35\n\x07srcType\x18\x05 \x01(\x0e\x32$.yeying.api.common.DigitalFormatEnum\x12\x35\n\x07\x64\x65sType\x18\x06 \x01(\x0e\x32$.yeying.api.common.DigitalFormatEnum\x12\x30\n\ntextPrompt\x18\x07 \x01(\x0b\x32\x1a.yeying.api.llm.TextPromptH\x00\x12\x32\n\x0bimagePrompt\x18\x08 \x01(\x0b\x32\x1b.yeying.api.llm.ImagePromptH\x00\x12\x32\n\x0bimageResult\x18\t \x01(\x0b\x32\x1b.yeying.api.llm.ImageResultH\x01\x42\x08\n\x06promptB\x08\n\x06result"l\n\x0c\x45\x64itResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus\x12\x10\n\x06\x62\x61se64\x18\x02 \x01(\tH\x00\x12\x0f\n\x05\x62ytes\x18\x03 \x01(\x0cH\x00\x42\x06\n\x04\x64\x61ta"@\n\x10TranslateRequest\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\r\n\x05llmId\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t"F\n\x11TranslateResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus">\n\x0e\x43onvertRequest\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12\r\n\x05llmId\x18\x02 \x01(\t\x12\x10\n\x08instance\x18\x03 \x01(\t"D\n\x0f\x43onvertResponse\x12\x31\n\x06status\x18\x01 \x01(\x0b\x32!.yeying.api.common.ResponseStatus"\x86\x01\n\x06\x43hoice\x12\r\n\x05index\x18\x01 \x01(\x05\x12-\n\x04role\x18\x02 \x01(\x0e\x32\x1f.yeying.api.llm.MessageRoleEnum\x12(\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x17.yeying.api.llm.Content\x12\x14\n\x0c\x66inishReason\x18\x04 \x01(\t"\x0f\n\rSpeechRequest"\x10\n\x0eSpeechResponse*w\n\x0fMessageRoleEnum\x12\x18\n\x14MESSAGE_ROLE_UNKNOWN\x10\x00\x12\x1a\n\x16MESSAGE_ROLE_ASSISTANT\x10\x01\x12\x15\n\x11MESSAGE_ROLE_USER\x10\x02\x12\x17\n\x13MESSAGE_ROLE_SYSTEM\x10\x03*\xa5\x01\n\x0f\x43ontentTypeEnum\x12\x18\n\x14\x43ONTENT_TYPE_UNKNOWN\x10\x00\x12\x15\n\x11\x43ONTENT_TYPE_TEXT\x10\x01\x12\x16\n\x12\x43ONTENT_TYPE_IMAGE\x10\x02\x12\x16\n\x12\x43ONTENT_TYPE_AUDIO\x10\x03\x12\x16\n\x12\x43ONTENT_TYPE_VIDEO\x10\x04\x12\x19\n\x15\x43ONTENT_TYPE_DOCUMENT\x10\x05\x32\x91\x03\n\x03Llm\x12R\n\tTranslate\x12 .yeying.api.llm.TranslateRequest\x1a!.yeying.api.llm.TranslateResponse"\x00\x12Q\n\x08\x43omplete\x12\x1f.yeying.api.llm.CompleteRequest\x1a .yeying.api.llm.CompleteResponse"\x00\x30\x01\x12\x45\n\x04\x45\x64it\x12\x1b.yeying.api.llm.EditRequest\x1a\x1c.yeying.api.llm.EditResponse"\x00\x30\x01\x12Q\n\x08Generate\x12\x1f.yeying.api.llm.GenerateRequest\x1a .yeying.api.llm.GenerateResponse"\x00\x30\x01\x12I\n\x06Speech\x12\x1d.yeying.api.llm.SpeechRequest\x1a\x1e.yeying.api.llm.SpeechResponse"\x00\x42\x10Z\x0eyeying/api/llmb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.llm.llm_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\016yeying/api/llm"
    _globals["_MESSAGEROLEENUM"]._serialized_start = 3404
    _globals["_MESSAGEROLEENUM"]._serialized_end = 3523
    _globals["_CONTENTTYPEENUM"]._serialized_start = 3526
    _globals["_CONTENTTYPEENUM"]._serialized_end = 3691
    _globals["_COMPLETEREQUEST"]._serialized_start = 107
    _globals["_COMPLETEREQUEST"]._serialized_end = 225
    _globals["_COMPLETEREQUESTBODY"]._serialized_start = 228
    _globals["_COMPLETEREQUESTBODY"]._serialized_end = 380
    _globals["_MESSAGE"]._serialized_start = 382
    _globals["_MESSAGE"]._serialized_end = 480
    _globals["_CONTENT"]._serialized_start = 482
    _globals["_CONTENT"]._serialized_end = 552
    _globals["_ANSWER"]._serialized_start = 554
    _globals["_ANSWER"]._serialized_end = 649
    _globals["_COMPLETERESPONSE"]._serialized_start = 652
    _globals["_COMPLETERESPONSE"]._serialized_end = 840
    _globals["_COMPLETERESPONSEHEAD"]._serialized_start = 843
    _globals["_COMPLETERESPONSEHEAD"]._serialized_end = 971
    _globals["_COMPLETERESPONSEHEADBODY"]._serialized_start = 973
    _globals["_COMPLETERESPONSEHEADBODY"]._serialized_end = 1050
    _globals["_COMPLETERESPONSEBODY"]._serialized_start = 1052
    _globals["_COMPLETERESPONSEBODY"]._serialized_end = 1088
    _globals["_COMPLETERESPONSETAIL"]._serialized_start = 1091
    _globals["_COMPLETERESPONSETAIL"]._serialized_end = 1219
    _globals["_COMPLETERESPONSETAILBODY"]._serialized_start = 1221
    _globals["_COMPLETERESPONSETAILBODY"]._serialized_end = 1298
    _globals["_GENERATEREQUEST"]._serialized_start = 1300
    _globals["_GENERATEREQUEST"]._serialized_end = 1418
    _globals["_GENERATEREQUESTBODY"]._serialized_start = 1421
    _globals["_GENERATEREQUESTBODY"]._serialized_end = 1618
    _globals["_GENERATERESPONSE"]._serialized_start = 1621
    _globals["_GENERATERESPONSE"]._serialized_end = 1809
    _globals["_GENERATERESPONSEHEAD"]._serialized_start = 1812
    _globals["_GENERATERESPONSEHEAD"]._serialized_end = 1940
    _globals["_GENERATERESPONSEHEADBODY"]._serialized_start = 1942
    _globals["_GENERATERESPONSEHEADBODY"]._serialized_end = 2019
    _globals["_GENERATERESPONSEBODY"]._serialized_start = 2021
    _globals["_GENERATERESPONSEBODY"]._serialized_end = 2057
    _globals["_GENERATERESPONSETAIL"]._serialized_start = 2060
    _globals["_GENERATERESPONSETAIL"]._serialized_end = 2188
    _globals["_GENERATERESPONSETAILBODY"]._serialized_start = 2190
    _globals["_GENERATERESPONSETAILBODY"]._serialized_end = 2267
    _globals["_TEXTPROMPT"]._serialized_start = 2269
    _globals["_TEXTPROMPT"]._serialized_end = 2298
    _globals["_IMAGEPROMPT"]._serialized_start = 2300
    _globals["_IMAGEPROMPT"]._serialized_end = 2359
    _globals["_IMAGERESULT"]._serialized_start = 2362
    _globals["_IMAGERESULT"]._serialized_end = 2505
    _globals["_EDITREQUEST"]._serialized_start = 2508
    _globals["_EDITREQUEST"]._serialized_end = 2848
    _globals["_EDITRESPONSE"]._serialized_start = 2850
    _globals["_EDITRESPONSE"]._serialized_end = 2958
    _globals["_TRANSLATEREQUEST"]._serialized_start = 2960
    _globals["_TRANSLATEREQUEST"]._serialized_end = 3024
    _globals["_TRANSLATERESPONSE"]._serialized_start = 3026
    _globals["_TRANSLATERESPONSE"]._serialized_end = 3096
    _globals["_CONVERTREQUEST"]._serialized_start = 3098
    _globals["_CONVERTREQUEST"]._serialized_end = 3160
    _globals["_CONVERTRESPONSE"]._serialized_start = 3162
    _globals["_CONVERTRESPONSE"]._serialized_end = 3230
    _globals["_CHOICE"]._serialized_start = 3233
    _globals["_CHOICE"]._serialized_end = 3367
    _globals["_SPEECHREQUEST"]._serialized_start = 3369
    _globals["_SPEECHREQUEST"]._serialized_end = 3384
    _globals["_SPEECHRESPONSE"]._serialized_start = 3386
    _globals["_SPEECHRESPONSE"]._serialized_end = 3402
    _globals["_LLM"]._serialized_start = 3694
    _globals["_LLM"]._serialized_end = 4095
# @@protoc_insertion_point(module_scope)



# -*- coding:utf-8 -*-
from google.protobuf.json_format import MessageToJson
from yeying.api.asset import recycle_pb2_grpc, recycle_pb2, asset_pb2
from yeying.api.common import ResponseCodeEnum, message_pb2
from yeying.client.provider.base_provider import BaseProvider
import grpc
from yeying.client.utils import log_utils

log = log_utils.get_logger(__name__)


"""
资产仓库资源回收站 CURD
"""


class RecycleProvider(BaseProvider):

    def __init__(self, **kw):
        super(RecycleProvider, self).__init__(**kw)
        # 资产元信息
        self.recycle_client = recycle_pb2_grpc.RecycleStub(grpc.insecure_channel(self.option.proxy))

    def search(self, page: int, page_size: int, condition: asset_pb2.SearchAssetCondition) -> recycle_pb2.SearchDeletedAssetResponse:
        body = recycle_pb2.SearchDeletedAssetRequestBody(condition=condition, page=message_pb2.RequestPage(page=page, pageSize=page_size))
        header = self.authenticate.create_header(body=body)
        request = recycle_pb2.SearchDeletedAssetRequest(header=header, body=body)
        response: recycle_pb2.SearchDeletedAssetResponse = self.recycle_client.Search(request)

        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"search error, response={MessageToJson(response)}")
        return response

    def recover(
        self, namespace_id: str, _hash: str
    ) -> recycle_pb2.RecoverDeletedAssetResponse:
        body = recycle_pb2.RecoverDeletedAssetRequestBody(hash=_hash, namespaceId=namespace_id)
        header = self.authenticate.create_header(body=body)
        request = recycle_pb2.RecoverDeletedAssetRequest(header=header, body=body)
        response: recycle_pb2.RecoverDeletedAssetResponse = self.recycle_client.Recover(request)

        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"recover error, response={MessageToJson(response)}")
        return response

    def remove(self, namespace_id: str, _hash: str) -> recycle_pb2.RemoveDeletedAssetResponse:
        body = recycle_pb2.RemoveDeletedAssetRequestBody(hash=_hash, namespaceId=namespace_id)
        header = self.authenticate.create_header(body=body)
        request = recycle_pb2.RemoveDeletedAssetRequest(header=header, body=body)
        response: recycle_pb2.RemoveDeletedAssetResponse = self.recycle_client.Remove(request)

        if ResponseCodeEnum.OK != response.body.status.code:
            raise Exception(f"remove error, response={MessageToJson(response)}")
        return response



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yeying/api/network/registry.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 28, 1, "", "yeying/api/network/registry.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yeying.api.common import code_pb2 as yeying_dot_api_dot_common_dot_code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n!yeying/api/network/registry.proto\x12\x0eyeying.network\x1a\x1cyeying/api/common/code.proto"\r\n\x0bListRequest":\n\x0cListResponse\x12*\n\x08\x63ontract\x18\x01 \x03(\x0b\x32\x18.yeying.network.Contract"j\n\x0b\x45xitRequest\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12"\n\x04peer\x18\x02 \x01(\x0b\x32\x14.yeying.network.Peer\x12*\n\x08\x63ontract\x18\x03 \x01(\x0b\x32\x18.yeying.network.Contract"\x12\n\x04Peer\x12\n\n\x02id\x18\x01 \x01(\t"\x1e\n\x0c\x45xitResponse\x12\x0e\n\x06status\x18\x01 \x01(\t"j\n\x0bJoinRequest\x12\x0b\n\x03\x64id\x18\x01 \x01(\t\x12"\n\x04peer\x18\x02 \x01(\x0b\x32\x14.yeying.network.Peer\x12*\n\x08\x63ontract\x18\x03 \x01(\x0b\x32\x18.yeying.network.Contract"j\n\x0cJoinResponse\x12.\n\x06status\x18\x01 \x01(\x0e\x32\x1e.yeying.network.RegisterStatus\x12*\n\x08\x63ontract\x18\x02 \x01(\x0b\x32\x18.yeying.network.Contract"\x1b\n\x08\x43ontract\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t*-\n\x0eRegisterStatus\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0e\n\nREGISTERED\x10\x01\x32\xd8\x01\n\x07Network\x12\x43\n\x04List\x12\x1b.yeying.network.ListRequest\x1a\x1c.yeying.network.ListResponse"\x00\x12\x43\n\x04Join\x12\x1b.yeying.network.JoinRequest\x1a\x1c.yeying.network.JoinResponse"\x00\x12\x43\n\x04\x45xit\x12\x1b.yeying.network.ExitRequest\x1a\x1c.yeying.network.ExitResponse"\x00\x42\x14Z\x12yeying/api/networkb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "yeying.api.network.registry_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals["DESCRIPTOR"]._serialized_options = b"Z\022yeying/api/network"
    _globals["_REGISTERSTATUS"]._serialized_start = 563
    _globals["_REGISTERSTATUS"]._serialized_end = 608
    _globals["_LISTREQUEST"]._serialized_start = 83
    _globals["_LISTREQUEST"]._serialized_end = 96
    _globals["_LISTRESPONSE"]._serialized_start = 98
    _globals["_LISTRESPONSE"]._serialized_end = 156
    _globals["_EXITREQUEST"]._serialized_start = 158
    _globals["_EXITREQUEST"]._serialized_end = 264
    _globals["_PEER"]._serialized_start = 266
    _globals["_PEER"]._serialized_end = 284
    _globals["_EXITRESPONSE"]._serialized_start = 286
    _globals["_EXITRESPONSE"]._serialized_end = 316
    _globals["_JOINREQUEST"]._serialized_start = 318
    _globals["_JOINREQUEST"]._serialized_end = 424
    _globals["_JOINRESPONSE"]._serialized_start = 426
    _globals["_JOINRESPONSE"]._serialized_end = 532
    _globals["_CONTRACT"]._serialized_start = 534
    _globals["_CONTRACT"]._serialized_end = 561
    _globals["_NETWORK"]._serialized_start = 611
    _globals["_NETWORK"]._serialized_end = 827
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yeying.api.warehouse import warehouse_pb2 as yeying_dot_api_dot_warehouse_dot_warehouse__pb2

GRPC_GENERATED_VERSION = "1.68.1"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + f" but the generated code in yeying/api/warehouse/warehouse_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class WarehouseStub(object):
    """*

    开放的分散式仓库网络的接口设计，参考了现实世界中的仓库，逻辑如下：
    1、数字资产有两个标识，一个是数字资产的身份标识，可以是分布式数字身份，也可以是用户自定义的身份ID，另一个是数字资产内容的哈希值；
    2、数字资产入库，发送到指定存储网络中的节点，可以指定副本数量，一方面保证内容不会因为单个节点故障而丢失，另外也保证内容的可访问性；
    3、存储复用，如果两份资产哈希值一样，分两种情况来看，如果资产的所有者一样，则仓库会主动告知身份持有者存在重复，如果资产的所有者不同，会增加引用；
    4、授权数字资产，所有者和使用者立交易关系，确保使用者根据指定的策略访问数据，仓库会统计数字资产的使用情况，比如统计内容取（浏览）的次数评估内容热度
    ，或者统计内容存的次数（收藏）评估内容质量，目的是更好的分配存储资源；

    分散式存储网络的使用场景：
    1、创作场景，知识产权证明
    2、代码包分发场景，比如软件包，模型包等
    3、数字资产，类似nft等
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetState = channel.unary_unary(
            "/yeying.api.store.Warehouse/GetState",
            request_serializer=yeying_dot_api_dot_warehouse_dot_warehouse__pb2.GetStateRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_warehouse_dot_warehouse__pb2.GetStateResponse.FromString,
            _registered_method=True,
        )
        self.Transfer = channel.unary_unary(
            "/yeying.api.store.Warehouse/Transfer",
            request_serializer=yeying_dot_api_dot_warehouse_dot_warehouse__pb2.TransferRequest.SerializeToString,
            response_deserializer=yeying_dot_api_dot_warehouse_dot_warehouse__pb2.GetStateResponse.FromString,
            _registered_method=True,
        )


class WarehouseServicer(object):
    """*

    开放的分散式仓库网络的接口设计，参考了现实世界中的仓库，逻辑如下：
    1、数字资产有两个标识，一个是数字资产的身份标识，可以是分布式数字身份，也可以是用户自定义的身份ID，另一个是数字资产内容的哈希值；
    2、数字资产入库，发送到指定存储网络中的节点，可以指定副本数量，一方面保证内容不会因为单个节点故障而丢失，另外也保证内容的可访问性；
    3、存储复用，如果两份资产哈希值一样，分两种情况来看，如果资产的所有者一样，则仓库会主动告知身份持有者存在重复，如果资产的所有者不同，会增加引用；
    4、授权数字资产，所有者和使用者立交易关系，确保使用者根据指定的策略访问数据，仓库会统计数字资产的使用情况，比如统计内容取（浏览）的次数评估内容热度
    ，或者统计内容存的次数（收藏）评估内容质量，目的是更好的分配存储资源；

    分散式存储网络的使用场景：
    1、创作场景，知识产权证明
    2、代码包分发场景，比如软件包，模型包等
    3、数字资产，类似nft等
    """

    def GetState(self, request, context):
        """*
        仓库和仓库之间同步数字资产，或者用户和仓库者之间
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Transfer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_WarehouseServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetState": grpc.unary_unary_rpc_method_handler(
            servicer.GetState,
            request_deserializer=yeying_dot_api_dot_warehouse_dot_warehouse__pb2.GetStateRequest.FromString,
            response_serializer=yeying_dot_api_dot_warehouse_dot_warehouse__pb2.GetStateResponse.SerializeToString,
        ),
        "Transfer": grpc.unary_unary_rpc_method_handler(
            servicer.Transfer,
            request_deserializer=yeying_dot_api_dot_warehouse_dot_warehouse__pb2.TransferRequest.FromString,
            response_serializer=yeying_dot_api_dot_warehouse_dot_warehouse__pb2.GetStateResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("yeying.api.store.Warehouse", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("yeying.api.store.Warehouse", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class Warehouse(object):
    """*

    开放的分散式仓库网络的接口设计，参考了现实世界中的仓库，逻辑如下：
    1、数字资产有两个标识，一个是数字资产的身份标识，可以是分布式数字身份，也可以是用户自定义的身份ID，另一个是数字资产内容的哈希值；
    2、数字资产入库，发送到指定存储网络中的节点，可以指定副本数量，一方面保证内容不会因为单个节点故障而丢失，另外也保证内容的可访问性；
    3、存储复用，如果两份资产哈希值一样，分两种情况来看，如果资产的所有者一样，则仓库会主动告知身份持有者存在重复，如果资产的所有者不同，会增加引用；
    4、授权数字资产，所有者和使用者立交易关系，确保使用者根据指定的策略访问数据，仓库会统计数字资产的使用情况，比如统计内容取（浏览）的次数评估内容热度
    ，或者统计内容存的次数（收藏）评估内容质量，目的是更好的分配存储资源；

    分散式存储网络的使用场景：
    1、创作场景，知识产权证明
    2、代码包分发场景，比如软件包，模型包等
    3、数字资产，类似nft等
    """

    @staticmethod
    def GetState(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.store.Warehouse/GetState",
            yeying_dot_api_dot_warehouse_dot_warehouse__pb2.GetStateRequest.SerializeToString,
            yeying_dot_api_dot_warehouse_dot_warehouse__pb2.GetStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def Transfer(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/yeying.api.store.Warehouse/Transfer",
            yeying_dot_api_dot_warehouse_dot_warehouse__pb2.TransferRequest.SerializeToString,
            yeying_dot_api_dot_warehouse_dot_warehouse__pb2.GetStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )
